@@ -3,6 +3,7 @@
 """po2md command line interface."""
 
 import argparse
+import itertools
 import sys
 
 from mdpo.cli import (
@@ -36,9 +37,10 @@ def build_parser():
              ' If not provided, will be read from STDIN.',
     )
     parser.add_argument(
-        '-p', '--pofiles', metavar='POFILES',
+        '-p', '--pofiles', metavar='POFILES', action='append', nargs='*',
         help='Glob matching a set of PO files from where to extract references'
-             ' to make the replacements translating strings.',
+             ' to make the replacements translating strings. This argument'
+             ' can be passed multiple times.',
     )
     parser.add_argument(
         '-i', '--ignore', dest='ignore', default=[],
@@ -90,6 +92,8 @@ def parse_options(args):
         opts.command_aliases,
     )
 
+    opts.pofiles = set(itertools.chain(*opts.pofiles))  # flatten
+
     return opts
 
 
